(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     78259,       1791]
NotebookOptionsPosition[     77109,       1765]
NotebookOutlinePosition[     77462,       1781]
CellTagsIndexPosition[     77419,       1778]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Analyzing Trajectories of Oxygen Drops in an Azimuthal-Symmetric Magnetic \
Field\
\>", "Title",
 CellChangeTimes->{{3.771664754370411*^9, 3.771664772864553*^9}, {
  3.7716666919134407`*^9, 3.771666700287704*^9}, {3.771666746933196*^9, 
  3.771666748899271*^9}},ExpressionUUID->"29a4fdc8-2f34-434b-b75d-\
ae6150503940"],

Cell[TextData[{
 "Version 1.2\n\n",
 StyleBox["Update in 1.2: Plot legends and labels have been added.\nUpdate in \
1.1: I added a mean filter to make the trajectory smooth.", "Subtitle",
  FontSize->18]
}], "Subtitle",
 CellChangeTimes->{{3.771664999078787*^9, 3.771665007454619*^9}, {
  3.772249655754393*^9, 
  3.772249737951173*^9}},ExpressionUUID->"cf8d43a4-f29e-4630-ac03-\
d2a534adbf57"],

Cell[TextData[{
 StyleBox["This program imports text files that contain the trajectories of \
oxygen drops (each file corresponds to a single trajectory) and analyses them \
in order to obtain useful information. In each text file, the first column \
must contain the x coordinates, the second column must contain the y \
coordinates, and the third column must contain the t (time) values. It is \
recommended (for useful analysis) that every batch of files you import should \
have oxygen drops with roughly the same initial velocity.", "Subtitle",
  FontSize->18],
 "\n\n\nThe program requires you to ",
 StyleBox["specify the directory",
  FontColor->RGBColor[
   0.2392309452964065, 0.4814831769283589, 0.7259784847791256]],
 " of the folder that contains the batch of data files you want to analyse, \
and then imports them for analysis. The loop runs over the files, one at a \
time, and stores the data in arrays. It then uses the data to calculate the \
experimental values of the peri-center of the trajectory, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "p"], ",", " ", 
    RowBox[{"and", " ", "the", " "}]}], TraditionalForm]],ExpressionUUID->
  "7f3c154e-8f0c-4248-8db3-9624599da270"],
 "angle of deflection, \[Alpha]. The next part of the program calculates the \
experimental values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "p"], " ", "and", " ", 
    RowBox[{"\[Alpha]", ".", " "}]}], TraditionalForm]],ExpressionUUID->
  "ea00c2e9-137b-4a9f-8b2b-760066368f9c"],
 "To achieve this, you must ",
 StyleBox["enter values for the fitting parameters",
  FontColor->RGBColor[
   0.2392309452964065, 0.4814831769283589, 0.7259784847791256]],
 " (a1, a2, a3) for the magnetic field profile. The program calculates the \
theoretical values for each drop separately. However, since a complete curve \
for the theoretical values may be more useful, the last part of the program \
uses the average value of the initial velocity of the batch of drops being \
analysed, and gives the theoretically predicted values in the form of a curve \
(the user may view the experimental values superposed on this curve to \
compare values)."
}], "Subsubtitle",
 CellChangeTimes->{{3.771664789503435*^9, 3.771664990078993*^9}, {
   3.771665074475501*^9, 3.771665075761524*^9}, 3.771665146953272*^9, {
   3.771665185048321*^9, 3.771665339887807*^9}, 3.771665626790062*^9, {
   3.771665774151106*^9, 3.771665774359394*^9}, {3.771666768869279*^9, 
   3.771666808870363*^9}, {3.771666856972231*^9, 3.77166686137041*^9}, {
   3.7716669133867683`*^9, 3.7716669246000547`*^9}, {3.771667279962975*^9, 
   3.7716674247889023`*^9}},ExpressionUUID->"5cd579ad-9adc-446c-a54a-\
60a884b46f09"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a1", "=", "66.9"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2", "=", "0.008886"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3", "=", "0.3122"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", " ", "=", " ", "1141"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"Solve", "::", "ratnz"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"NIntegrate", "::", "ncvb"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7718401619950123`*^9, 3.7718401624856896`*^9}, {
  3.772249217723987*^9, 3.772249218707244*^9}},
 CellLabel->
  "In[229]:=",ExpressionUUID->"80017953-4f9d-41cb-899d-77db51558041"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"files", " ", "=", " ", 
   RowBox[{"FileNames", "[", 
    RowBox[{
    "\"\<*.txt\>\"", ",", 
     "\"\</Users/airfan/Documents/OneDrive - Higher Education \
Commission/summer2019@physlab/Experimental Data/session_1/all files/\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"analyseddata", " ", "=", " ", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"total", "=", 
   RowBox[{"Length", "[", "files", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.771839723470728*^9, 3.771839831868025*^9}, {
  3.7718400810847993`*^9, 3.771840096661454*^9}, {3.772247913108779*^9, 
  3.7722479140908833`*^9}},
 CellLabel->
  "In[235]:=",ExpressionUUID->"f62ae254-4487-4a4e-b9d3-9843cf4a94a9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", " ", "=", " ", "1"}], ",", " ", 
    RowBox[{"i", "<", 
     RowBox[{"total", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", " ", 
    RowBox[{
     RowBox[{"data", " ", "=", " ", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{"files", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", "\"\<Table\>\""}], "]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     StyleBox[
      RowBox[{"(*", 
       RowBox[{
       "Calculating", " ", "experimental", " ", "values", " ", "of", " ", 
        StyleBox[
         RowBox[{"require", 
          StyleBox[
           StyleBox["d", "Section",
            
            FontColor->RGBColor[
             0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
           "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]]}]], 
        StyleBox[" ", "Section",
         FontColor->RGBColor[
          0.08593881132219425, 0.4571145189593347, 0.021988250553139545`]], 
        "variables"}], "*)"}], "Section",
      FontColor->RGBColor[
       0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
     StyleBox["\n", "Section",
      FontColor->RGBColor[
       0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
     "\[IndentingNewLine]", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"data", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", " ", "1"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"data", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", " ", "2"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"t", " ", "=", " ", 
      RowBox[{"data", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", " ", "3"}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "x", "]"}]}], ";", "\n", 
     RowBox[{"x", " ", "=", " ", 
      RowBox[{"MeanFilter", "[", 
       RowBox[{"x", ",", " ", "3"}], "]"}]}], ";", "\n", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{"MeanFilter", "[", 
       RowBox[{"y", ",", " ", "3"}], "]"}]}], ";", "\n", 
     RowBox[{"Delete", "[", 
      RowBox[{"x", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", " ", 
         RowBox[{"{", "2", "}"}], ",", " ", 
         RowBox[{"{", "3", "}"}], ",", " ", 
         RowBox[{"{", "n", "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", "-", "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", "-", "2"}], "}"}]}], "}"}]}], "]"}], ";", "\n", 
     RowBox[{"Delete", "[", 
      RowBox[{"y", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", " ", 
         RowBox[{"{", "2", "}"}], ",", " ", 
         RowBox[{"{", "3", "}"}], ",", " ", 
         RowBox[{"{", "n", "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", "-", "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", "-", "2"}], "}"}]}], "}"}]}], "]"}], ";", "\n", 
     RowBox[{"Delete", "[", 
      RowBox[{"t", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", " ", 
         RowBox[{"{", "2", "}"}], ",", " ", 
         RowBox[{"{", "3", "}"}], ",", " ", 
         RowBox[{"{", "n", "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", "-", "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", "-", "2"}], "}"}]}], "}"}]}], "]"}], ";", "\n", 
     RowBox[{"cartesiantrajectory", " ", "=", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "y"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"polartrajectory", " ", "=", " ", 
      RowBox[{"CoordinateTransform", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Cartesian\>\"", "->", "\"\<Polar\>\""}], "}"}], ",", 
        "cartesiantrajectory"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"polartrajectory", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", " ", "1"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Theta]", " ", "=", " ", 
      RowBox[{"polartrajectory", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", " ", "2"}], "]"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"dx", " ", "=", " ", 
      RowBox[{"Differences", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dt", " ", "=", " ", 
      RowBox[{"Differences", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dr", " ", "=", " ", 
      RowBox[{"Differences", "[", "r", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["v", "x"], "=", " ", 
      FractionBox["dx", "dt"]}], ";", "\[IndentingNewLine]", 
     RowBox[{"V", "=", 
      RowBox[{"Mean", "[", 
       RowBox[{
        SubscriptBox["v", "x"], "[", 
        RowBox[{"[", 
         RowBox[{"1", ";;", "10"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["v", "r"], "=", " ", 
      FractionBox["dr", "dt"]}], ";", "\[IndentingNewLine]", 
     RowBox[{"b", " ", "=", " ", 
      RowBox[{"Abs", "[", 
       RowBox[{"Mean", "[", 
        RowBox[{"y", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "10"}], "]"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["r", "p"], "=", " ", 
      RowBox[{"Part", "[", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"[", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Abs", "[", 
              SubscriptBox["v", "r"], "]"}], ",", " ", 
             RowBox[{"Min", "[", 
              RowBox[{"Abs", "[", 
               SubscriptBox["v", "r"], "]"}], "]"}]}], "]"}], "]"}], "]"}], 
         "]"}], ",", " ", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"hypotenuse", " ", "=", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"y", "[", 
             RowBox[{"[", "n", "]"}], "]"}], " ", "-", " ", 
            RowBox[{"y", "[", 
             RowBox[{"[", 
              RowBox[{"n", "-", "20"}], "]"}], "]"}]}], ")"}], "2"], " ", "+",
          " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", "[", 
             RowBox[{"[", "n", "]"}], "]"}], " ", "-", " ", 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"n", "-", "20"}], "]"}], "]"}]}], ")"}], "2"]}], ")"}], 
       
       FractionBox["1", "2"]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"perpendicular", " ", "=", " ", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"[", "n", "]"}], "]"}], " ", "-", " ", 
       RowBox[{"y", "[", 
        RowBox[{"[", 
         RowBox[{"n", "-", "20"}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"base", " ", "=", " ", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", "n", "]"}], "]"}], " ", "-", " ", 
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"n", "-", "20"}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]", "=", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{"Abs", "[", "perpendicular", "]"}], 
        RowBox[{"Abs", "[", "base", "]"}]], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"base", " ", ">", " ", "0"}], " ", "&&", " ", 
         RowBox[{"perpendicular", ">", "0"}]}], ")"}], ",", " ", 
       RowBox[{"\[Alpha]", "=", "\[Alpha]"}], ",", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"base", " ", "<", " ", "0"}], " ", "&&", " ", 
           RowBox[{"perpendicular", ">", "0"}]}], ")"}], ",", " ", 
         RowBox[{"\[Alpha]", "=", " ", 
          RowBox[{"\[Pi]", "-", "\[Alpha]"}]}], ",", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"base", " ", "<", " ", "0"}], " ", "&&", " ", 
             RowBox[{"perpendicular", "<", "0"}]}], ")"}], ",", " ", 
           RowBox[{"\[Alpha]", "=", " ", 
            RowBox[{"\[Pi]", "+", "\[Alpha]"}]}], ",", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"base", " ", ">", " ", "0"}], " ", "&&", " ", 
               RowBox[{"perpendicular", "<", "0"}]}], ")"}], ",", " ", 
             RowBox[{"\[Alpha]", " ", "=", " ", 
              RowBox[{
               RowBox[{"2", "\[Pi]"}], "-", "\[Alpha]"}]}]}], "]"}]}], 
          "]"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]", " ", "=", " ", 
      RowBox[{
       FractionBox["180", "\[Pi]"], "\[Alpha]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     StyleBox[
      RowBox[{"(*", 
       RowBox[{"Calculating", " ", 
        StyleBox[
         RowBox[{
          StyleBox["t", "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
          StyleBox[
           StyleBox[
            StyleBox["h", "Section",
             
             FontColor->RGBColor[
              0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
            "Section",
            
            FontColor->RGBColor[
             0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
           "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
          "eo", 
          StyleBox[
           StyleBox[
            StyleBox["r", "Section",
             
             FontColor->RGBColor[
              0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
            "Section",
            
            FontColor->RGBColor[
             0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
           "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
          "et", 
          StyleBox[
           StyleBox[
            StyleBox["i", "Section",
             
             FontColor->RGBColor[
              0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
            "Section",
            
            FontColor->RGBColor[
             0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
           "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
          "ca", 
          StyleBox["l", "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]]}]], 
        " ", "values", " ", "of", " ", 
        StyleBox[
         RowBox[{
          StyleBox["r", "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
          "equire", 
          StyleBox["d", "Section",
           
           FontColor->RGBColor[
            0.2392309452964065, 0.4814831769283589, 0.7259784847791256]]}]], 
        StyleBox[" ", "Section",
         FontColor->RGBColor[
          0.08593881132219425, 0.4571145189593347, 0.021988250553139545`]], 
        "variables"}], "*)"}], "Section",
      FontColor->RGBColor[
       0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
     "\[IndentingNewLine]", "\n", 
     RowBox[{"a1", "=", "66.9"}], ";", "\n", 
     RowBox[{"a2", "=", "0.008886"}], ";", "\n", 
     RowBox[{"a3", "=", "0.3122"}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Rho]", " ", "=", " ", "1141"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["E", "mag"], "[", "R_", "]"}], ":=", 
      RowBox[{"-", 
       FractionBox["a1", 
        RowBox[{"a3", " ", "+", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["R", "a2"], ")"}], "6"]}]]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["E", "eff"], "[", "R_", "]"}], ":=", 
      RowBox[{
       RowBox[{
        SubscriptBox["E", "mag"], "[", "R", "]"}], " ", "+", " ", 
       FractionBox[
        RowBox[{"\[Rho]", " ", 
         SuperscriptBox["b", "2"], 
         SuperscriptBox["V", "2"]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["R", "2"]}]]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["E", "initial"], "[", "R_", "]"}], "=", " ", 
      FractionBox[
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["V", "2"]}], "2"]}], ";", "\[IndentingNewLine]", 
     RowBox[{"solutions", " ", "=", " ", 
      RowBox[{"Values", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["E", "eff"], "[", "R", "]"}], "\[Equal]", 
          RowBox[{
           SubscriptBox["E", "initial"], "[", "R", "]"}]}], ",", " ", 
         RowBox[{"{", "R", "}"}], ",", " ", "Reals"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["r", 
       SubscriptBox["p", "theoretical"]], "=", " ", 
      RowBox[{"Abs", "[", 
       RowBox[{"solutions", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "[", "R_", "]"}], ":=", 
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["R", "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", 
             RowBox[{
              SubscriptBox["E", "eff"], "[", "R", "]"}]}], 
            RowBox[{"\[Rho]", " ", 
             SuperscriptBox["V", "2"]}]]}], ")"}], 
         FractionBox["1", "2"]]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"f", "[", "R", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"R", ",", " ", "0", ",", " ", "0.2"}], "}"}]}], "]"}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["\[Alpha]", "theoretical"], "=", 
      RowBox[{
       FractionBox["180", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "b", " ", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"f", "[", "R", "]"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"R", ",", " ", 
              SubscriptBox["r", 
               SubscriptBox["p", "theoretical"]], ",", " ", "\[Infinity]"}], 
             "}"}]}], "]"}]}], " ", "-", " ", "\[Pi]"}], ")"}]}]}], ";", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"analyseddata", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["r", "p"], ",", " ", 
         SubscriptBox["r", 
          SubscriptBox["p", "theoretical"]], ",", " ", "\[Alpha]", ",", " ", 
         SubscriptBox["\[Alpha]", "theoretical"], ",", " ", "b", ",", " ", 
         "V"}], "}"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"analyseddata", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["valuesr", "p"], " ", "=", " ", 
   RowBox[{"analyseddata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", " ", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["valuesr", 
    SubscriptBox["p", "theoretical"]], "=", 
   RowBox[{"analyseddata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", " ", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"values\[Alpha]", "=", 
   RowBox[{"analyseddata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", " ", "3"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["values\[Alpha]", "theoretical"], "=", 
   RowBox[{"analyseddata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", " ", "4"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"analyseddata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", " ", "5"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V", "=", 
   RowBox[{"analyseddata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", " ", "6"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Thread", "[", 
      RowBox[{"{", 
       RowBox[{"b", ",", " ", 
        SubscriptBox["valuesr", "p"]}], "}"}], "]"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<\!\(\*SubscriptBox[\(r\), \(p\)]\)\>\"", "}"}]}], ",",
      " ", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<b (m)\>\"", ",", " ", 
        "\"\<\!\(\*SubscriptBox[\(r\), \(p\)]\) (m)\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Thread", "[", 
      RowBox[{"{", 
       RowBox[{"b", ",", " ", 
        SubscriptBox["valuesr", 
         SubscriptBox["p", "theoretical"]]}], "}"}], "]"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<b (m)\>\"", ",", " ", 
        "\"\<\!\(\*SubscriptBox[\(r\), SubscriptBox[\(p\), \
\(theoretical\)]]\) (m)\>\""}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Thread", "[", 
      RowBox[{"{", 
       RowBox[{"b", ",", " ", "values\[Alpha]"}], "}"}], "]"}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", "\"\<\[Alpha]\>\"", "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<b (m)\>\"", ",", " ", "\"\<\[Alpha] (degrees)\>\""}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p4", " ", "=", " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{"b", ",", " ", 
         SubscriptBox["values\[Alpha]", "theoretical"]}], "}"}], "]"}], ",", 
      " ", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<b (m)\>\"", ",", " ", 
         "\"\<\!\(\*SubscriptBox[\(\[Alpha]\), \(\(theoretical\)\(\\\ \
\)\)]\)(degrees)\>\""}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"Calculating", " ", 
     StyleBox[
      RowBox[{
       StyleBox["t", "Section",
        FontColor->RGBColor[
         0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
       StyleBox[
        StyleBox[
         StyleBox["h", "Section",
          
          FontColor->RGBColor[
           0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
         "Section",
         FontColor->RGBColor[
          0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
        "Section",
        FontColor->RGBColor[
         0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], "eo", 
       StyleBox[
        StyleBox[
         StyleBox["r", "Section",
          
          FontColor->RGBColor[
           0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
         "Section",
         FontColor->RGBColor[
          0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
        "Section",
        FontColor->RGBColor[
         0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], "et", 
       StyleBox[
        StyleBox[
         StyleBox["i", "Section",
          
          FontColor->RGBColor[
           0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
         "Section",
         FontColor->RGBColor[
          0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
        "Section",
        FontColor->RGBColor[
         0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], "ca", 
       StyleBox["l", "Section",
        FontColor->RGBColor[
         0.2392309452964065, 0.4814831769283589, 0.7259784847791256]]}]], " ",
      "values", " ", "of", " ", 
     StyleBox[
      RowBox[{
       StyleBox["r", "Section",
        FontColor->RGBColor[
         0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
       "equire", 
       StyleBox["d", "Section",
        FontColor->RGBColor[
         0.2392309452964065, 0.4814831769283589, 0.7259784847791256]]}]], 
     StyleBox[" ", "Section",
      FontColor->RGBColor[
       0.08593881132219425, 0.4571145189593347, 0.021988250553139545`]], 
     "variables", " ", "using", " ", "the", " ", "average", " ", "velocity"}],
     "*)"}], "Section",
   FontColor->RGBColor[
    0.2392309452964065, 0.4814831769283589, 0.7259784847791256]], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"V", "=", " ", 
   RowBox[{"Mean", "[", "V", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]data", " ", "=", " ", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rdata", " ", "=", " ", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"b", "=", "0.0005"}], ",", " ", 
   RowBox[{"b", "<", "0.03"}], ",", " ", 
   RowBox[{"b", "=", 
    RowBox[{"b", "+", "0.0001"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["E", "mag"], "[", "R_", "]"}], ":=", 
     RowBox[{"-", 
      FractionBox["a1", 
       RowBox[{"a3", " ", "+", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["R", "a2"], ")"}], "6"]}]]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["E", "eff"], "[", "R_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       SubscriptBox["E", "mag"], "[", "R", "]"}], " ", "+", " ", 
      FractionBox[
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["b", "2"], 
        SuperscriptBox["V", "2"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}]]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["E", "initial"], "[", "R_", "]"}], "=", " ", 
     FractionBox[
      RowBox[{"\[Rho]", " ", 
       SuperscriptBox["V", "2"]}], "2"]}], ";", "\[IndentingNewLine]", 
    RowBox[{"solutions", " ", "=", " ", 
     RowBox[{"Values", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["E", "eff"], "[", "R", "]"}], "\[Equal]", 
         RowBox[{
          SubscriptBox["E", "initial"], "[", "R", "]"}]}], ",", " ", 
        RowBox[{"{", "R", "}"}], ",", " ", "Reals"}], "]"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["r", 
      SubscriptBox["p", "theoretical"]], "=", " ", 
     RowBox[{"Abs", "[", 
      RowBox[{"solutions", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f", "[", "R_", "]"}], ":=", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["R", "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{
             SubscriptBox["E", "eff"], "[", "R", "]"}]}], 
           RowBox[{"\[Rho]", " ", 
            SuperscriptBox["V", "2"]}]]}], ")"}], 
        FractionBox["1", "2"]]}]]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["\[Alpha]", "theoretical"], "=", 
     RowBox[{
      FractionBox["180", "\[Pi]"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "b", " ", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"f", "[", "R", "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"R", ",", " ", 
             SubscriptBox["r", 
              SubscriptBox["p", "theoretical"]], ",", " ", "\[Infinity]"}], 
            "}"}]}], "]"}]}], " ", "-", " ", "\[Pi]"}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"\[Alpha]data", ",", " ", 
      RowBox[{"{", 
       RowBox[{"b", ",", 
        SubscriptBox["\[Alpha]", "theoretical"]}], "}"}]}], "]"}], ";", "\n", 
    
    RowBox[{"AppendTo", "[", 
     RowBox[{"rdata", ",", " ", 
      RowBox[{"{", 
       RowBox[{"b", ",", " ", 
        SubscriptBox["r", 
         SubscriptBox["p", "theoretical"]]}], "}"}]}], "]"}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Code",
 CellChangeTimes->{
  3.771666957310686*^9, {3.771667017707859*^9, 3.771667026701334*^9}, {
   3.771667066611802*^9, 3.7716671006444893`*^9}, {3.7716671357745123`*^9, 
   3.7716672189015408`*^9}, 3.771667259390259*^9, {3.771667479097722*^9, 
   3.77166749131566*^9}, {3.771667528942623*^9, 3.771667614142161*^9}, {
   3.771667678077026*^9, 3.771667733435401*^9}, {3.771667800725664*^9, 
   3.771667815979067*^9}, {3.771667848748583*^9, 3.771667850171568*^9}, {
   3.771668436179953*^9, 3.771668437820573*^9}, 3.7716684707530813`*^9, {
   3.771669112428653*^9, 3.771669143108552*^9}, {3.7716692323942757`*^9, 
   3.771669253932612*^9}, {3.771669323116808*^9, 3.77166935909446*^9}, 
   3.771688258922348*^9, {3.771839486684741*^9, 3.7718394946012*^9}, 
   3.771839625770835*^9, {3.771840107321643*^9, 3.771840135129593*^9}, {
   3.7718405409603014`*^9, 3.7718405626176567`*^9}, {3.771840748797454*^9, 
   3.7718407496930914`*^9}, {3.7722483936415987`*^9, 3.772248468225366*^9}, {
   3.772248586083887*^9, 3.7722485892100897`*^9}, {3.772249438064357*^9, 
   3.772249486079761*^9}, {3.772249553597144*^9, 
   3.772249575027307*^9}},ExpressionUUID->"15140bb4-7ccc-49f4-8dbd-\
3cfb7f12d944"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p5", " ", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"\[Alpha]data", ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{
      "{", "\"\<\!\(\*SubscriptBox[\(\[Alpha]\), \(theoretical\)]\)\>\"", 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p6", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"rdata", ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{
      "{", "\"\<\!\(\*SubscriptBox[SubscriptBox[\(r\), \(p\)], \
\(theoretical\)]\)\>\"", "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", " ", "p6", ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
      RowBox[{
      "Framed", "[", 
       "\"\<A comparison of the experimental and theoretical values of \
\!\(\*SubscriptBox[\(r\), \(p\)]\)\>\"", "]"}], ",", "12", ",", "Black", ",", 
      
      RowBox[{"Background", "\[Rule]", 
       RowBox[{"Lighter", "[", "LightBlue", "]"}]}]}], "]"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p3", ",", " ", "p5", ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
      RowBox[{
      "Framed", "[", 
       "\"\<A comparison of the experimental and theoretical values of \
\[Alpha]\>\"", "]"}], ",", "12", ",", "Black", ",", 
      RowBox[{"Background", "\[Rule]", 
       RowBox[{"Lighter", "[", "LightBlue", "]"}]}]}], "]"}]}]}], 
  "]"}]}], "Input",
 CellFrame->{{0, 0}, {3, 0}},
 CellChangeTimes->{{3.772248214643203*^9, 3.772248219673018*^9}, {
  3.772248253018526*^9, 3.772248258684997*^9}, {3.772248293960451*^9, 
  3.772248330132328*^9}, {3.772248609679965*^9, 3.772248654983994*^9}, {
  3.77224871110769*^9, 3.772248813159768*^9}, {3.77224887894169*^9, 
  3.772248966869589*^9}, {3.772249259216619*^9, 3.772249266620669*^9}, {
  3.77224937624646*^9, 3.772249389004702*^9}},
 CellLabel->
  "In[293]:=",ExpressionUUID->"ac5be6c8-52ed-4e93-8ba2-97d1e83b1743"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQrRW1jN+hf4r91olNyg81ptif4kotyrk7wX6C4bSs
XpsJ9pN8Dz448qLL/rjnnbfbLdrsfwWuOZj6rcP+nPz1c+IvGuzzNt3stWec
a39JK6JJ/M4ceymhL8vNp06zT2S5/b05aZq9HmvKJJbF/fah4sFXDTb12nf5
ZHHoTOmyz7I2nV5f0mg/6RfjrPZlc+z7PKWPZTTNsU+Z9crx8Jpp9jZ3Line
KJhmf6Nua9mO8732712VN7xL7rS/vDum5fCtbvtSDpmY+g1t9mbmYb9izrTa
n15zulhjSpV91AUbqU3rO+xZvqxdk7aj0X5Wk2X2793d9jPbL1Ye+9piP9L8
CwCmwOsS
          "]]}, {}}}, {}, {}, {}, {}}, {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          PointSize[Medium]], 
         PointBox[CompressedData["
1:eJwtlnc81f0bxlGp9GinpF/RECKpHk9Cl1SaisyMsrP3TvY4jnX2PjQ9SAsN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          "]]}, {}}}, {}, {}, {}, {}}}, {PlotLabel -> FormBox[
       StyleBox[
        FrameBox[
        "\"A comparison of the experimental and theoretical values of \
\\!\\(\\*SubscriptBox[\\(r\\), \\(p\\)]\\)\"", StripOnInput -> False], 12, 
        GrayLevel[0], Background -> RGBColor[0.9133333333333333, 0.96, 1], 
        StripOnInput -> False], TraditionalForm], DisplayFunction -> Identity,
      PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0.010367426608440809`, 0}, 
     PlotRange -> {{0.010643698110267868`, 0.02832507422719959}, {
       0, 0.028183333712187793`}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"b (m)\"", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(r\\), \\(p\\)]\\) (m)\"", 
        TraditionalForm]}, AxesOrigin -> {0.010367426608440809`, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.010643698110267868`, 0.02832507422719959}, {
       0, 0.028183333712187793`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"\\!\\(\\*SubscriptBox[\\(r\\), \\(p\\)]\\)\""}, 
          "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.462], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.462], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), 
          InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
          "\"\\!\\(\\*SubscriptBox[SubscriptBox[\\(r\\), \\(p\\)], \
\\(theoretical\\)]\\)\""}, "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    PointSize[Medium]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    PointSize[Medium]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), 
          InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Medium", "]"}]}], "]"}], "}"}],
                ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.771667236418086*^9, {3.771667464866798*^9, 3.771667493539247*^9}, 
   3.7716675390333652`*^9, 3.771667618106489*^9, {3.771667699750174*^9, 
   3.7716677339385653`*^9}, 3.7716678028808327`*^9, 3.7716684716058073`*^9, 
   3.771669114084546*^9, 3.771669146128327*^9, {3.771669325011389*^9, 
   3.771669360117505*^9}, 3.7718395579295254`*^9, 3.77183962821917*^9, 
   3.7718401826561284`*^9, {3.7722483422551327`*^9, 3.772248371383031*^9}, 
   3.7722484929738894`*^9, {3.772248598008047*^9, 3.772248626995448*^9}, 
   3.772248657800256*^9, {3.7722487625833683`*^9, 3.772248768235108*^9}, {
   3.7722487982725677`*^9, 3.772248813957615*^9}, {3.772248879984742*^9, 
   3.772248909301791*^9}, {3.772248950063435*^9, 3.772248967381977*^9}, 
   3.772249053295601*^9, {3.7722492386530523`*^9, 3.7722492670428133`*^9}, 
   3.772249391162067*^9, 3.7722494968256474`*^9, 3.772249599194956*^9},
 CellLabel->
  "Out[295]=",ExpressionUUID->"298c5058-9222-43f2-83c4-6729dec9f360"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         PointBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQrRW1jN+hf4q9o1lx++8jog6nuFKLcu5OsH85N+VI
9DEdh0m+Bx8cedFlP9fIrP1QQYDDr8A1B1O/ddgnRv7UUr4a7ZC36WavPeNc
e56Tj7V3rWNwkBL6stx86jT730sY2T+4sDnosaZMYlncbz8hVbhqwlUThy6f
LA6dKV32T67sL5DziXaY9ItxVvuyOfba7OEB24tYHVJmvXI8vGaafbzoVeE3
ovwON+q2lu0432u/cmMV58MIN4fLu2NaDt/qtn/D+nRVUHWAg5l52K+YM632
hhb35lcYhztEXbCR2rS+w74wet7B29xRDrOaLLN/7+62n6NnVZvBFOEw0vwL
ANqk26o=
          "]]}, {}}}, {}, {}, {}, {}}, {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          PointSize[Medium]], 
         PointBox[CompressedData["
1:eJwtlnc8FewbxiWpRITXaBglKS0ZReq6lZWSlfKiQpFQhGRF9j72Hr2l8VJK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          
          "]]}, {}}}, {}, {}, {}, {}}}, {PlotLabel -> FormBox[
       StyleBox[
        FrameBox[
        "\"A comparison of the experimental and theoretical values of \
\[Alpha]\"", StripOnInput -> False], 12, 
        GrayLevel[0], Background -> RGBColor[0.9133333333333333, 0.96, 1], 
        StripOnInput -> False], TraditionalForm], DisplayFunction -> Identity,
      PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0.010367426608440809`, 0}, 
     PlotRange -> {{0.010643698110267868`, 0.02832507422719959}, {
       0, 111.33027147627355`}}, PlotRangeClipping -> True, ImagePadding -> 
     All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"b (m)\"", TraditionalForm], 
       FormBox["\"\[Alpha] (degrees)\"", TraditionalForm]}, 
     AxesOrigin -> {0.010367426608440809`, 0}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.010643698110267868`, 0.02832507422719959}, {
       0, 111.33027147627355`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"\[Alpha]\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.462], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.462], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), 
          InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                   "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
          "\"\\!\\(\\*SubscriptBox[\\(\[Alpha]\\), \\(theoretical\\)]\\)\""}, 
          "PointLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    PointSize[Medium]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    PointSize[Medium]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), 
          InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Medium", "]"}]}], "]"}], "}"}],
                ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.771667236418086*^9, {3.771667464866798*^9, 3.771667493539247*^9}, 
   3.7716675390333652`*^9, 3.771667618106489*^9, {3.771667699750174*^9, 
   3.7716677339385653`*^9}, 3.7716678028808327`*^9, 3.7716684716058073`*^9, 
   3.771669114084546*^9, 3.771669146128327*^9, {3.771669325011389*^9, 
   3.771669360117505*^9}, 3.7718395579295254`*^9, 3.77183962821917*^9, 
   3.7718401826561284`*^9, {3.7722483422551327`*^9, 3.772248371383031*^9}, 
   3.7722484929738894`*^9, {3.772248598008047*^9, 3.772248626995448*^9}, 
   3.772248657800256*^9, {3.7722487625833683`*^9, 3.772248768235108*^9}, {
   3.7722487982725677`*^9, 3.772248813957615*^9}, {3.772248879984742*^9, 
   3.772248909301791*^9}, {3.772248950063435*^9, 3.772248967381977*^9}, 
   3.772249053295601*^9, {3.7722492386530523`*^9, 3.7722492670428133`*^9}, 
   3.772249391162067*^9, 3.7722494968256474`*^9, 3.772249599270132*^9},
 CellLabel->
  "Out[296]=",ExpressionUUID->"70b13f0c-8a64-4f68-9e6b-fcbd9f8f5260"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1440, 661},
WindowMargins->{{0, Automatic}, {Automatic, 2}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 329, 7, 160, "Title",ExpressionUUID->"29a4fdc8-2f34-434b-b75d-ae6150503940"],
Cell[912, 31, 394, 9, 133, "Subtitle",ExpressionUUID->"cf8d43a4-f29e-4630-ac03-d2a534adbf57"],
Cell[1309, 42, 2713, 50, 241, "Subsubtitle",ExpressionUUID->"5cd579ad-9adc-446c-a54a-60a884b46f09"],
Cell[4025, 94, 737, 20, 157, "Input",ExpressionUUID->"80017953-4f9d-41cb-899d-77db51558041"],
Cell[4765, 116, 845, 20, 94, "Input",ExpressionUUID->"f62ae254-4487-4a4e-b9d3-9843cf4a94a9"],
Cell[5613, 138, 26179, 714, 1930, "Code",ExpressionUUID->"15140bb4-7ccc-49f4-8dbd-3cfb7f12d944"],
Cell[CellGroupData[{
Cell[31817, 856, 2204, 54, 110, "Input",ExpressionUUID->"ac5be6c8-52ed-4e93-8ba2-97d1e83b1743"],
Cell[34024, 912, 21526, 423, 269, "Output",ExpressionUUID->"298c5058-9222-43f2-83c4-6729dec9f360"],
Cell[55553, 1337, 21528, 424, 265, "Output",ExpressionUUID->"70b13f0c-8a64-4f68-9e6b-fcbd9f8f5260"]
}, Open  ]]
}, Open  ]]
}
]
*)

